@@ -1,11 +1,9 @@
 from humps import decamelize
 
-from ..serializable import Serializable
-
 NORMALIZED_KEYS = frozenset(('from', 'type'))
 
 
-class DictToClass(Serializable):
+class DictToClass:
     """Turns a dictionary into a class."""
 
     def __init__(self, dictionary: dict, class_type: type) -> None:
